@@ -188,10 +188,6 @@ impl Syntax {
         }
     }
 
-    pub const fn num_sep(self) -> bool {
-        true
-    }
-
     pub fn decorators(self) -> bool {
         match self {
             Syntax::Es(EsConfig {
@@ -204,18 +200,6 @@ impl Syntax {
         }
     }
 
-    pub const fn class_private_methods(self) -> bool {
-        true
-    }
-
-    pub const fn class_private_props(self) -> bool {
-        true
-    }
-
-    pub const fn class_props(self) -> bool {
-        true
-    }
-
     pub fn decorators_before_export(self) -> bool {
         match self {
             Syntax::Es(EsConfig {
@@ -252,24 +236,6 @@ impl Syntax {
         }
     }
 
-    /// `true`
-    pub const fn export_namespace_from(self) -> bool {
-        true
-    }
-
-    /// `true`
-    pub const fn nullish_coalescing(self) -> bool {
-        true
-    }
-
-    pub const fn import_meta(self) -> bool {
-        true
-    }
-
-    pub const fn top_level_await(self) -> bool {
-        true
-    }
-
     pub fn dts(self) -> bool {
         match self {
             Syntax::Typescript(t) => t.dts,
@@ -295,7 +261,7 @@ impl Syntax {
 }
 
 #[derive(Debug, Clone, Copy, Default, Serialize, Deserialize)]
-#[serde(deny_unknown_fields, rename_all = "camelCase")]
+#[serde(rename_all = "camelCase")]
 pub struct TsConfig {
     #[serde(default)]
     pub tsx: bool,
@@ -303,9 +269,6 @@ pub struct TsConfig {
     #[serde(default)]
     pub decorators: bool,
 
-    #[serde(default)]
-    pub dynamic_import: bool,
-
     /// `.d.ts`
     #[serde(skip, default)]
     pub dts: bool,
@@ -315,27 +278,10 @@ pub struct TsConfig {
 }
 
 #[derive(Debug, Clone, Copy, Default, Serialize, Deserialize)]
-#[serde(deny_unknown_fields, rename_all = "camelCase")]
+#[serde(rename_all = "camelCase")]
 pub struct EsConfig {
     #[serde(default)]
     pub jsx: bool,
-    /// Support numeric separator.
-    /// Stage 3.
-    #[serde(rename = "numericSeparator")]
-    #[serde(default)]
-    pub num_sep: bool,
-
-    #[serde(rename = "classPrivateProperty")]
-    #[serde(default)]
-    pub class_private_props: bool,
-
-    #[serde(rename = "privateMethod")]
-    #[serde(default)]
-    pub class_private_methods: bool,
-
-    #[serde(rename = "classProperty")]
-    #[serde(default)]
-    pub class_props: bool,
 
     /// Support function bind expression.
     #[serde(rename = "functionBind")]
@@ -356,27 +302,6 @@ pub struct EsConfig {
     #[serde(default)]
     pub export_default_from: bool,
 
-    #[serde(default)]
-    pub export_namespace_from: bool,
-
-    #[serde(default)]
-    pub dynamic_import: bool,
-
-    /// Stage 3.
-    #[serde(default)]
-    pub nullish_coalescing: bool,
-
-    #[serde(default)]
-    pub optional_chaining: bool,
-
-    /// Stage 3.
-    #[serde(default)]
-    pub import_meta: bool,
-
-    /// Stage 3.
-    #[serde(default)]
-    pub top_level_await: bool,
-
     /// Stage 3.
     #[serde(default)]
     pub import_assertions: bool,
