@@ -249,7 +249,7 @@ impl<'a, I: Tokens> Parser<I> {
 
                 tok!("import") => {
                     let import = self.parse_ident_name()?;
-                    if self.input.syntax().import_meta() && is!(self, '.') {
+                    if is!(self, '.') {
                         self.state.found_module_item = true;
                         if !self.ctx().can_be_module {
                             let span = span!(self, start);
@@ -1664,10 +1664,6 @@ impl<'a, I: Tokens> Parser<I> {
         start: BytePos,
         import_ident: Ident,
     ) -> PResult<Box<Expr>> {
-        if !self.input.syntax().dynamic_import() {
-            syntax_error!(self, span!(self, start), SyntaxError::DynamicImport);
-        }
-
         let args = self.parse_args(true)?;
         let import = Box::new(Expr::Call(CallExpr {
             span: span!(self, start),
